package com.link.core.webservice;

import com.link.core.basic.dao.BasicDaoException;
import com.link.core.util.CoreYmlConstants;
import com.link.core.util.DateUtil;
import java.util.Iterator;
import java.util.Set;
import javax.xml.namespace.QName;
import javax.xml.soap.SOAPElement;
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeader;
import javax.xml.soap.SOAPHeaderElement;
import javax.xml.soap.SOAPMessage;
import javax.xml.ws.handler.MessageContext;
import javax.xml.ws.handler.soap.SOAPHandler;
import javax.xml.ws.handler.soap.SOAPMessageContext;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class SiebelHeaderHandler implements SOAPHandler<SOAPMessageContext> {
   private static final Logger logger = LogManager.getLogger(SiebelHeaderHandler.class);
   private static String sessionToken;
   private static Long lastTime;
   private final Long maxTime = 600000L;
   private final String sessionType = "Stateless";

   public static String getSessionToken() {
      return sessionToken;
   }

   public static void setSessionToken(String sessionToken) {
      SiebelHeaderHandler.sessionToken = sessionToken;
   }

   public static Long getLastTime() {
      return lastTime;
   }

   public static void setLastTime(Long lastTime) {
      SiebelHeaderHandler.lastTime = lastTime;
   }

   public boolean handleMessage(SOAPMessageContext context) {
      Boolean isRequest = (Boolean)context.get("javax.xml.ws.handler.message.outbound");
      QName usernameQName = new QName("http://siebel.com/webservices", "UsernameToken", "siebelwsh");
      QName passwordQName = new QName("http://siebel.com/webservices", "PasswordText", "siebelwsh");
      QName sessionTypeQName = new QName("http://siebel.com/webservices", "SessionType", "siebelwsh");
      QName sessionTokenQName = new QName("http://siebel.com/webservices", "SessionToken", "siebelwsh");
      Exception e;
      String currentSessionToken;
      SOAPException e;
      SOAPMessage soapMsg;
      if (isRequest) {
         try {
            soapMsg = context.getMessage();
            SOAPEnvelope soapEnv = soapMsg.getSOAPPart().getEnvelope();
            SOAPHeader soapHeader = soapEnv.getHeader();
            soapEnv.addNamespaceDeclaration("siebelwsh", "http://siebel.com/webservices");
            if (soapHeader == null) {
               soapHeader = soapEnv.addHeader();
            }

            SOAPHeaderElement usernameHeaderElement;
            if (sessionToken != null && !sessionToken.isEmpty() && DateUtil.getCurrentLongTime() - lastTime < this.maxTime) {
               usernameHeaderElement = soapHeader.addHeaderElement(sessionTokenQName);
               usernameHeaderElement.addTextNode(sessionToken);
               SOAPHeaderElement SessionTypeHeaderElement = soapHeader.addHeaderElement(sessionTypeQName);
               SessionTypeHeaderElement.addTextNode("Stateless");
            } else {
               lastTime = DateUtil.getCurrentLongTime();
               sessionToken = null;
               usernameHeaderElement = soapHeader.addHeaderElement(usernameQName);
               currentSessionToken = CoreYmlConstants.getSiebelWebserviceUsername();
               usernameHeaderElement.addTextNode(currentSessionToken);
               SOAPHeaderElement passwordHeaderElement = soapHeader.addHeaderElement(passwordQName);
               String password = CoreYmlConstants.getSiebelWebservicePassword();
               passwordHeaderElement.addTextNode(password);
               SOAPHeaderElement SessionTypeHeaderElement = soapHeader.addHeaderElement(sessionTypeQName);
               SessionTypeHeaderElement.addTextNode("Stateless");
            }

            soapMsg.saveChanges();
         } catch (SOAPException var17) {
            e = var17;
            logger.warn(e.getMessage());
         } catch (Exception var18) {
            e = var18;
            logger.error(e.getMessage(), e);
         }
      } else {
         try {
            soapMsg = context.getMessage();
            SOAPHeader soapHeader = soapMsg.getSOAPHeader();
            Iterator<SOAPElement> iter = soapHeader.getChildElements(sessionTokenQName);

            while(true) {
               do {
                  if (!iter.hasNext()) {
                     return true;
                  }

                  SOAPElement sessionTokenElement = (SOAPElement)iter.next();
                  currentSessionToken = sessionTokenElement.getTextContent();
                  logger.debug("sessionToken : " + currentSessionToken);
               } while(sessionToken != null && !sessionToken.isEmpty());

               sessionToken = currentSessionToken;
               lastTime = DateUtil.getCurrentLongTime();
            }
         } catch (SOAPException var15) {
            e = var15;
            logger.warn(e.getMessage());
         } catch (Exception var16) {
            e = var16;
            logger.error(e.getMessage(), e);
         }
      }

      return true;
   }

   public boolean handleFault(SOAPMessageContext context) {
      try {
         logger.warn("webservice 错误");
         QName sessionTokenQName = new QName("http://siebel.com/webservices", "SessionToken", "siebelwsh");
         SOAPMessage soapMsg = context.getMessage();
         SOAPHeader soapHeader = soapMsg.getSOAPHeader();
         Iterator<SOAPElement> iter = soapHeader.getChildElements(sessionTokenQName);
         if (iter.hasNext()) {
            SOAPElement sessionTokenElement = (SOAPElement)iter.next();
            String currentSessionToken = sessionTokenElement.getTextContent();
            logger.debug("sessionToken : " + currentSessionToken);
            if (sessionToken == null || sessionToken.isEmpty()) {
               sessionToken = currentSessionToken;
               lastTime = DateUtil.getCurrentLongTime();
            }
         } else {
            sessionToken = null;
            logger.warn("关闭Webservice Session");
         }
      } catch (Exception var9) {
         Exception e = var9;
         logger.error(e.getMessage(), e);

         try {
            throw new BasicDaoException("链接sieble接口错误，请稍后重试" + e.getMessage());
         } catch (BasicDaoException var8) {
            BasicDaoException e1 = var8;
            logger.error("SiebelHeaderHandler捕获异常: ", e1);
         }
      }

      return true;
   }

   public void close(MessageContext context) {
   }

   public Set<QName> getHeaders() {
      return null;
   }
}
